Renamed templates + added some filters for mail order
[mailer.git] / ref.php
diff --git a/ref.php b/ref.php
index 06f3030707f18b4accdb8aa1f7a24b85fa72061b..dec75785e1f38458dfb949a81b8f77d218372f2c 100644 (file)
--- a/ref.php
+++ b/ref.php
@@ -6,9 +6,9 @@
  * -------------------------------------------------------------------- *
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
* Short description : Redirection for the referal link                 *
  * -------------------------------------------------------------------- *
* Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
  * -------------------------------------------------------------------- *
  * $Revision::                                                        $ *
  * $Date::                                                            $ *
@@ -16,8 +16,8 @@
  * $Author::                                                          $ *
  * -------------------------------------------------------------------- *
  * Copyright (c) 2003 - 2009 by Roland Haeder                           *
- * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
- * For more information visit: http://www.mxchange.org                  *
+ * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
+ * For more information visit: http://mxchange.org                      *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
  * it under the terms of the GNU General Public License as published by *
 // Load security stuff here
 require('inc/libs/security_functions.php');
 
+// Init start time
+$GLOBALS['__start_time'] = microtime(TRUE);
+
 // Set module
-$GLOBALS['module'] = 'ref';
-$GLOBALS['output_mode'] = -1;
+$GLOBALS['__module']      = 'ref';
+$GLOBALS['__output_mode'] = -1;
 
 // Load the required file(s)
 require('inc/config-global.php');
@@ -51,11 +54,10 @@ setContentType('text/html');
 // No refid by default
 $url = 'modules.php?module=index';
 
-// Check for determined referal id
-if ((isExtensionActive('user')) && (isReferalIdValid()) && (isValidUserId(determineReferalId()))) {
-       // Update ref counter
-       SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `ref_clicks`=`ref_clicks`+1 WHERE `userid`=%s LIMIT 1",
-               array(makeDatabaseUserId(determineReferalId())), __FILE__, __LINE__);
+// Check for determined referral id
+if ((isExtensionActive('user')) && (isValidReferralId()) && (isValidId(determineReferralId()))) {
+       // Run filter chain for updating referral data
+       runFilterChain('update_referral_data');
 
        // Base URL for redirection
        switch (getConfig('refid_target')) {
@@ -66,6 +68,10 @@ if ((isExtensionActive('user')) && (isReferalIdValid()) && (isValidUserId(determ
                case 'index':
                        $url = 'modules.php?module=index';
                        break;
+
+               default: // Is not valid
+                       reportBug(__FILE__, __LINE__, 'Invalid refid target ' . getConfig('refid_target') . ' detected.');
+                       break;
        } // END - switch
 } // END - if
@@ -6,9 +6,9 @@
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
- * Short description : Redirection for the referal link                 *
+ * Short description : Redirection for the referral link                *
  * -------------------------------------------------------------------- *
@@ -6,9 +6,9 @@
  * -------------------------------------------------------------------- *
- * Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
+ * Kurzbeschreibung  : Weiterleitungsscript fuer die Referral-Links     *
  * -------------------------------------------------------------------- *
  * $Revision::                                                        $ *